'use strict';

/* global module, require */

var defaults = require('./_utils.js').defaults;

var imagemin = function imagemin($, gulp, opts) {
    return function () {
        var config = defaults({
            optimizationLevel: 7,
            interlaced: true,
            progressive: true
        }, opts);

        return gulp.src(config.src).pipe($.newer(config.dest)).pipe($.imagemin({
            optimizationLevel: config.optimizationLevel,
            interlaced: config.interlaced,
            progressive: config.progressive
        })).pipe(gulp.dest(config.dest));
    };
};

var tinypng = function tinypng($, gulp, opts) {
    return function () {
        var config = defaults({
            log: true,
            key: 'Az7H_NvSjTuDEQ2x8QE9oFU2j7Kno3UT',
            sigFile: './webroot/.tinypng-sigs'
        }, opts);

        return gulp.src(config.src).pipe($.newer(config.dest)).pipe($.tinypngCompress({
            key: config.key,
            log: config.log,
            sigFile: config.sigFile
        })).pipe(gulp.dest(config.dest));
    };
};

var svgmin = function svgmin($, gulp, opts) {
    return function () {
        var config = defaults({
            plugins: [{ cleanupIDs: false }]
        }, opts);

        return gulp.src(config.src).pipe($.svgmin({
            plugins: config.plugins
        })).pipe(gulp.dest(config.dest));
    };
};

module.exports = {
    imagemin: imagemin,
    tinypng: tinypng,
    svgmin: svgmin
};