'use strict';

/* global module, require */

var defaults = require('./_utils.js').defaults;
var named = require('vinyl-named');
/**
   * Scripts
   *
   * @param  {object} $ - Helper object containing gulp plugins
   * @param  {function} gulp - Reference to the current version of gulp
   * @param  {object} opts - Options referenced below
   */
module.exports = function ($, gulp, opts) {
    return function () {
        /**
           * Merge the defaults with any options set
           * @type {object}
           * @param {boolean} isProduction - running in production mode (should minify or not)
           * @param {boolean} reload - should reload on save or not using browserSync
           * @param {object} webpack - webpack specific config settings
           */
        var config = defaults({
            isProduction: opts.isProduction,
            reload: true,
            webpack: {
                devtool: opts.isProduction ? '' : 'source-map',
                output: {
                    filename: '[name].js'
                },
                plugins: [],
                module: {
                    loaders: [{
                        exclude: /(node_modules|bower_components)/,
                        loader: 'babel-loader',
                        query: {
                            presets: ['es2015']
                        }
                    }]
                }
            }
        }, opts);

        if (config.isProduction) {
            // Merge the plugins from the options with these production specific ones.

            config.webpack.plugins.push(
            // set node environment to production
            new $.webpack.DefinePlugin({
                'process.env': {
                    'NODE_ENV': JSON.stringify('production')
                }
            }));

            // minify files
            config.webpack.plugins.push(new $.webpack.optimize.UglifyJsPlugin({
                compress: {
                    warnings: false
                }
            }));
        }

        return gulp.src(config.src)
        // run webpack on each file
        .pipe(named())
        // Explanation for the webpack config options can be found here:
        // https://webpack.js.org/configuration/
        .pipe($.webpackStream(config.webpack, $.webpack))
        // error logging
        .on('error', function (error) {
            $.util.log($.util.colors.red(error.message));
            this.emit('end');
        })
        // ouput location
        .pipe(gulp.dest(config.dest));
    };
};