'use strict';

/* global module, require */

var defaults = require('./_utils.js').defaults;

/**
   * stylelint
   *
   * @param  {object} $ - Helper object containing gulp plugins
   * @param  {function} gulp - Reference to the current version of gulp
   * @param  {object} opts - Options referenced above
   */
var stylelint = function stylelint($, gulp, opts) {
  return function () {
    var config = defaults({
      silent: false
    }, opts);

    var reporters = [];

    if (!config.silent) {
      reporters.push({
        formatter: 'verbose',
        console: true
      });
    }

    return gulp.src(config.src).pipe($.stylelint({
      syntax: 'scss',
      reporters: reporters,
      debug: !config.debug
    }));
  };
};

/**
   * eslint
   *
   * @param  {object} $ - Helper object containing gulp plugins
   * @param  {function} gulp - Reference to the current version of gulp
   * @param  {object} opts - Options referenced above
   */
var eslint = function eslint($, gulp, opts) {
  return function () {
    var config = defaults({
      silent: false
    }, opts);

    return gulp.src(config.src).pipe($.eslint()).pipe($.eslint.format()).pipe($.eslint.results(function (results) {
      if (!config.silent && results.warningCount > 0 || results.errorCount > 0) {
        throw new $.util.PluginError({
          plugin: 'ESLint',
          message: results.warningCount + ' warning ' + (results.warningCount !== 1 ? 's' : '') + '. ' + results.errorCount + ' error' + (results.errorCount !== 1 ? 's' : '') + '.'
        });
      }
    }));
  };
};

module.exports = {
  stylelint: stylelint,
  eslint: eslint
};