'use strict';

/* global module, require */

var defaults = require('./_utils.js').defaults;

/**
   * Styles
   *
   * @param {object} $ - Helper object containing gulp plugins
   * @param {function} gulp - Reference to the current version of gulp
   * @param {object} opts - Options referenced below
   */
module.exports = function ($, gulp, opts) {
    return function () {
        /**
           * Options
           * @type {object}
           * @param {boolean} isProduction - running in production mode (should minify or not)
           * @param {boolean} reload - should reload on save or not using browserSync
           * @param {array} browsers - array of browsers to prefix against
           * @param {string} style - Output style for sass
           */
        var config = defaults({
            isProduction: false,
            reload: true,
            browsers: ['last 3 versions', 'ie 11', 'ie 10'],
            style: 'expanded'
        }, opts);

        return gulp.src(config.src)
        // run sourcmaps if we're not on production
        .pipe(config.isProduction ? $.util.noop() : $.sourcemaps.init())
        // if we're on production, compress the CSS, if we're not, leave it as set in the options
        .pipe($.sass({
            outputStyle: config.style
        }).on('error', $.sass.logError)).pipe($.postcss([$.autoprefixer({
            browsers: config.browsers
        })])).pipe(config.isProduction ? $.cleanCss() : $.util.noop()).pipe($.rename({
            suffix: '.min'
        }))
        // run sourcmaps if we're not on production
        .pipe(config.isProduction ? $.util.noop() : $.sourcemaps.write('./')).pipe(gulp.dest(config.dest));
    };
};