/* global require */

/**
 * (c) 2017 Parallax Agency Ltd
 **/

'use strict';

/*---------- [ Gulp Plugins ] ----------*/
const gulp = require('gulp'),
  runSequence = require('run-sequence'),
  babel = require('gulp-babel'),
  $ = require('gulp-load-plugins')({
    pattern: ['gulp-*', 'gulp.*', 'webpack', 'webpack-stream'],
  });

/*---------- [ Asset Paths ] ----------*/
const watch = {
  sass: 'scss/**/*.scss',
  js: 'js/**/*.js',
  gulptasks: 'gulp-tasks/**/*.js'
};

/*---------- [ Top Level Tasks ] ----------*/
// run: gulp
gulp.task('default', ['build']);

// run: gulp watch
gulp.task('watch', ['watches']);

gulp.task('clean', () => {
  return gulp.src('dist')
    .pipe($.clean());
});

// run: gulp build
gulp.task('build', cb => {
  runSequence('clean', ['js', 'sass', 'gulptasks'], cb);
});

/*---------- [ Setup Tasks ] ----------*/
gulp.task('watches', ['build'], () => {
  gulp.watch(watch.js, ['jsLint', 'js']);
  gulp.watch(watch.sass, ['stylelint']);
  gulp.watch(watch.gulptasks, ['gulptasks']);
});

/*---------- [ JavaScript Tasks ] ----------*/
gulp.task('js', () => {
  gulp.src('src/**/*.js')
    .pipe(babel({
      presets: ['env']
    }))
    .pipe(gulp.dest('dist'))
});

gulp.task('jsLint', () => {
  return gulp.src(watch.js)
    .pipe($.eslint())
    .pipe($.eslint.format())
    .pipe($.eslint.results((results) => {
      if (results.warningCount > 0 || results.errorCount > 0) {
        throw new $.util.PluginError({
          plugin: 'ESLint',
          message: `${results.warningCount} warning ${(results.warningCount !== 1 ? 's' : '')}. ${results.errorCount} error${(results.errorCount !== 1 ? 's' : '')}.`,
        });
      }
    }));
});

/*---------- [ SASS Tasks ] ----------*/
gulp.task('sass', () => {
   gulp.src('./src/scss/**/*.scss')
   .pipe(gulp.dest('./dist/scss'));
});

gulp.task('stylelint', () => {
  return gulp.src(watch.sass)
    .pipe($.stylelint({
      syntax: 'scss',
      reporters: [{
        formatter: 'verbose',
        console: true,
      }],
      debug: true
    }));
});

/*---------- [ gulp-tasks Tasks ] ----------*/
gulp.task('gulptasks', () => {
   gulp.src('./gulp-tasks/**/*.js')
   .pipe(gulp.dest('./dist/gulp-tasks'));
});
